<?xml version="1.0"?>
<package format="3">
  <name>{{id}}_skill_msgs</name>
  <version>0.1.0</version>
  <description>{{name}}</description>

  <!-- One maintainer tag required, multiple allowed, one person per tag -->
  <!-- Example:  -->
  <!-- <maintainer email="jane.doe@example.com">Jane Doe</maintainer> -->
  <maintainer email="todo@todo.todo">TODO</maintainer>

  <!-- One license tag required, multiple allowed, one license per tag -->
  <!-- Commonly used license strings: -->
  <!--   BSD, MIT, Boost Software License, GPLv2, GPLv3, LGPLv2.1, LGPLv3 -->
  <license>Apache License 2.0</license>

  <!-- Url tags are optional, but multiple are allowed, one per tag -->
  <!-- Optional attribute type can be: website, bugtracker, or repository -->
  <!-- Example: -->
  <!-- <url type="website">http://wiki.ros.org/test</url> -->


  <!-- Author tags are optional, multiple are allowed, one per tag -->
  <!-- Authors do not have to be maintainers, but could be -->
  <!-- Example: -->
  <!-- <author email="jane.doe@example.com">Jane Doe</author> -->

  <buildtool_depend>ament_cmake_auto</buildtool_depend>
  <buildtool_depend>rosidl_default_generators</buildtool_depend>

  <depend>std_skills</depend>
  <depend>action_msgs</depend>
  <exec_depend>rosidl_default_runtime</exec_depend>

  <test_depend>ament_cmake_xmllint</test_depend>
  <test_depend>ament_cmake_archlint</test_depend>
  <test_depend>ament_lint_auto</test_depend>

  <member_of_group>rosidl_interface_packages</member_of_group>

  <export>
    <build_type>ament_cmake</build_type>
    <skill content-type="json">
      {
        "id": "{{id}}",
        "description": "{{name}}. [Write here what the skill is doing].",
        "interface": "action",
        "default_interface_path": "/skill/{{id}}",
        "datatype": "{{id}}_skill_msgs/action/{{Id}}",
        "parameters": {
          "in": [
            {
            "name": "skill_data",
            "type": "string",
            "description": "This parameter indicates..."
            }
        ]},
        "functional_domains": [
            "other"
        ]
      }
    </skill>
  </export>
</package>
