# Translations template for {{ id }}.
# Copyright (C) 2024 ORGANIZATION
# This file is distributed under the same license as the {{ id }} project.
# FIRST AUTHOR <EMAIL@ADDRESS>, 2024.
#
#, fuzzy
msgid ""
msgstr ""
"Project-Id-Version: test_4 0.1.0\n"
"Report-Msgid-Bugs-To: EMAIL@ADDRESS\n"
"POT-Creation-Date: 2024-11-21 17:05+0100\n"
"PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
"Language-Team: LANGUAGE <LL@li.org>\n"
"MIME-Version: 1.0\n"
"Content-Type: text/plain; charset=utf-8\n"
"Content-Transfer-Encoding: 8bit\n"
"Generated-By: Babel 2.8.0\n"

msgid "Hello, what can I do for you today?"
msgstr ""

{% if robot == "ari" %}
msgid "Hello, I'm ARI. Nice to meet you!"
msgstr ""
{% elif robot == "tiago" %}
msgid "Hello, I'm TIAGo. Nice to meet you!"
msgstr ""
{% endif %}

